# RawUnit

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **int** |  | [optional] [readonly] 
**name** | **str** |  | [optional] 
**type** | **str** |  | 
**unit_type** | **str** |  | [optional] 
**prefix** | **str** |  | [optional] 
**elements** | [**object**](.md) |  | [optional] 
**conversion_factor** | **float** |  | [optional] 
**dimensions** | **list[float]** |  | [optional] 
**conversion_baseunit_index** | **int** |  | [optional] 
**is_default** | **bool** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


